//
//
// Definition of classes
//
#ifndef _PLOTSCURVESALLDIFFFIT_H_
#define _PLOTSCURVESALLDIFFFIT_H_

#include <iostream>
#include "TString.h"
#include "PlotScurvesAll-diffFitConst.h"


class TCanvas;
class TH1D;
class TF1;

void PlotScurve(
		Int_t    kDrawCh=31,
		TString  fname=kFname,
		TString  fname_ped=kFnamePed, //ASIC_D ped_file
		Double_t dac_half_spe_fix = -1,
		TString  fname_gain="gain-org.txt",
		Int_t    fit_min=kFitMin,
		Int_t    fit_max=kFitMax,
		Int_t    fit_min_scurve=kFitMinS,
		Int_t    fit_max_scurve=kFitMaxS,
		Bool_t   kBoard=0, //0:ASIC_C, 1:ASIC_D
		Int_t    kChRef=kRefCh,//ASIC_C
		Bool_t   checkAve=0 //0:use ref pix, 1:check average
		);


//-------------------------------------------------------------
// Same work presented inside the analysis class
//
//
//-------------------------------------------------------------

class Analysis
{
 public:

  Analysis(); // construtor to clean variables, and create object on the heap

  ~Analysis(); // destructor to clean object form the heap 

  // Main analysis function to be called from outside

void PlotScurve(
		Int_t    kDrawCh,
		TString  fname,
		TString  fname_ped, //ASIC_D ped_file
		Double_t dac_half_spe_fix,
		TString  fname_gain,
		Int_t    fit_min,
		Int_t    fit_max,
		Int_t    fit_min_scurve,
		Int_t    fit_max_scurve,
		Bool_t   kBoard, //0:ASIC_C, 1:ASIC_D
		Int_t    kChRef,//ASIC_C
		Bool_t   checkAve //0:use ref pix, 1:check average
		);




private:

 void Init();
 void OpenGainFile(const TString);
 void FillHistoName();
 void ReadGainFile(const TString,Bool_t);

// common variables to the analysis
     TString *input;
     TString *input_ped;
     Int_t    ch;
     Float_t  dac_half_sum;  
     Float_t  dac_ped_sum;   
     Float_t  dac_spe_sum;    
     Float_t  dac_sfit_sum;     
     Float_t  diff_sum;      
     Float_t  mean_sum;       
     Float_t  maxBinSum;

// output of the PlotScurve Analysis
     Double_t dac_half[kNch];
     Double_t dac_ped[kNch];
     Double_t dac_spe[kNch];
     Double_t dac_sfit[kNch];
     Double_t mean_diff[kNch];
     Double_t gain_org[kNch];
     Double_t sfit_chiS[kNch];
     Double_t flag_fit[kNch];

     //canvas pointers

     TCanvas *c1; //smoothed S-curves
     TCanvas *c2; //differentiated histograms of smoothed s-curves
     TCanvas *c5;
     TCanvas *c3;            
     TCanvas *c4;

     //histograms

     TString  name_hist[kNch];
     TString  name_hist_ped[kNch];
     TString  name_hist_diff[kNch];
     TString  name_hist_diff_fit[kNch];
     TString  name_fit_diff[kNch];
     TH1D    *hist_scurve; // smoothed S-curves
     TH1D    *hist_scurve_ped; // S-curves for pedestal runs
     TH1D    *hist_diff; // differentiated histograms of smoothed s-curves
     TH1D    *hist_diff_fit; // differentiated histograms of fitted s-curves
     TF1     *fit_sdiff;  // function fitted on differentiated histograms of fitted s-curves


     

};

#endif

